@@ -9,7 +9,7 @@ describe 'keystone::cron::token_flush' do
   let :params do
     { :ensure      => 'present',
       :minute      => 1,
-      :hour        => 0,
+      :hour        => '*',
       :monthday    => '*',
       :month       => '*',
       :weekday     => '*',
@@ -29,7 +29,7 @@ describe 'keystone::cron::token_flush' do
         :monthday    => params[:monthday],
         :month       => params[:month],
         :weekday     => params[:weekday],
-        :require     => 'Package[keystone]',
+        :require     => 'Anchor[keystone::install::end]',
       )
     end
   end
@@ -52,7 +52,7 @@ describe 'keystone::cron::token_flush' do
         :monthday    => params[:monthday],
         :month       => params[:month],
         :weekday     => params[:weekday],
-        :require     => 'Package[keystone]',
+        :require     => 'Anchor[keystone::install::end]',
       )
     end
   end
@@ -71,11 +71,11 @@ describe 'keystone::cron::token_flush' do
         :environment => 'PATH=/bin:/usr/bin:/usr/sbin SHELL=/bin/sh',
         :user        => 'keystonecustom',
         :minute      => 1,
-        :hour        => 0,
+        :hour        => '*',
         :monthday    => '*',
         :month       => '*',
         :weekday     => '*',
-        :require     => 'Package[keystone]',
+        :require     => 'Anchor[keystone::install::end]',
       )
     end
   end
@@ -98,7 +98,7 @@ describe 'keystone::cron::token_flush' do
         :monthday    => params[:monthday],
         :month       => params[:month],
         :weekday     => params[:weekday],
-        :require     => 'Package[keystone]',
+        :require     => 'Anchor[keystone::install::end]',
       )
     end
   end
