@@ -4,88 +4,82 @@ describe 'keystone::ldap' do
   describe 'with basic params' do
     let :params do
       {
-        :url => 'ldap://foo',
-        :user => 'cn=foo,dc=example,dc=com',
-        :password => 'abcdefg',
-        :suffix => 'dc=example,dc=com',
-        :query_scope => 'sub',
-        :page_size => '50',
-        :user_tree_dn => 'cn=users,dc=example,dc=com',
-        :user_filter => '(memberOf=cn=openstack,cn=groups,cn=accounts,dc=example,dc=com)',
-        :user_objectclass => 'inetUser',
-        :user_id_attribute => 'uid',
-        :user_name_attribute => 'cn',
-        :user_mail_attribute => 'mail',
-        :user_enabled_attribute => 'UserAccountControl',
-        :user_enabled_mask => '2',
-        :user_enabled_default => '512',
-        :user_enabled_invert => 'False',
-        :user_attribute_ignore => '',
-        :user_default_project_id_attribute => 'defaultProject',
-        :user_allow_create => 'False',
-        :user_allow_update => 'False',
-        :user_allow_delete => 'False',
-        :user_pass_attribute => 'krbPassword',
-        :user_enabled_emulation => 'True',
-        :user_enabled_emulation_dn => 'cn=openstack-enabled,cn=groups,cn=accounts,dc=example,dc=com',
-        :user_additional_attribute_mapping => 'description:name, gecos:name',
-        :project_tree_dn => 'ou=projects,ou=openstack,dc=example,dc=com',
-        :project_filter => '',
-        :project_objectclass => 'organizationalUnit',
-        :project_id_attribute => 'ou',
-        :project_member_attribute => 'member',
-        :project_desc_attribute => 'description',
-        :project_name_attribute => 'ou',
-        :project_enabled_attribute => 'enabled',
-        :project_domain_id_attribute => 'businessCategory',
-        :project_attribute_ignore => '',
-        :project_allow_create => 'True',
-        :project_allow_update => 'True',
-        :project_allow_delete => 'True',
-        :project_enabled_emulation => 'False',
-        :project_enabled_emulation_dn => 'True',
+        :url                                  => 'ldap://foo',
+        :user                                 => 'cn=foo,dc=example,dc=com',
+        :password                             => 'abcdefg',
+        :suffix                               => 'dc=example,dc=com',
+        :query_scope                          => 'sub',
+        :page_size                            => '50',
+        :user_tree_dn                         => 'cn=users,dc=example,dc=com',
+        :user_filter                          => '(memberOf=cn=openstack,cn=groups,cn=accounts,dc=example,dc=com)',
+        :user_objectclass                     => 'inetUser',
+        :user_id_attribute                    => 'uid',
+        :user_name_attribute                  => 'cn',
+        :user_description_attribute           => 'description',
+        :user_mail_attribute                  => 'mail',
+        :user_enabled_attribute               => 'UserAccountControl',
+        :user_enabled_mask                    => '2',
+        :user_enabled_default                 => '512',
+        :user_enabled_invert                  => 'False',
+        :user_attribute_ignore                => '',
+        :user_default_project_id_attribute    => 'defaultProject',
+        :user_pass_attribute                  => 'krbPassword',
+        :user_enabled_emulation               => 'True',
+        :user_enabled_emulation_dn            => 'cn=openstack-enabled,cn=groups,cn=accounts,dc=example,dc=com',
+        :user_additional_attribute_mapping    => 'description:name, gecos:name',
+        :project_tree_dn                      => 'ou=projects,ou=openstack,dc=example,dc=com',
+        :project_filter                       => '',
+        :project_objectclass                  => 'organizationalUnit',
+        :project_id_attribute                 => 'ou',
+        :project_member_attribute             => 'member',
+        :project_desc_attribute               => 'description',
+        :project_name_attribute               => 'ou',
+        :project_enabled_attribute            => 'enabled',
+        :project_domain_id_attribute          => 'businessCategory',
+        :project_attribute_ignore             => '',
+        :project_allow_create                 => 'True',
+        :project_allow_update                 => 'True',
+        :project_allow_delete                 => 'True',
+        :project_enabled_emulation            => 'False',
+        :project_enabled_emulation_dn         => 'True',
         :project_additional_attribute_mapping => 'cn=enabled,ou=openstack,dc=example,dc=com',
-        :role_tree_dn => 'ou=roles,ou=openstack,dc=example,dc=com',
-        :role_filter => '',
-        :role_objectclass => 'organizationalRole',
-        :role_id_attribute => 'cn',
-        :role_name_attribute => 'ou',
-        :role_member_attribute => 'roleOccupant',
-        :role_attribute_ignore => 'description',
-        :role_allow_create => 'True',
-        :role_allow_update => 'True',
-        :role_allow_delete => 'True',
-        :role_additional_attribute_mapping => '',
-        :group_tree_dn => 'ou=groups,ou=openstack,dc=example,dc=com',
-        :group_filter => 'cn=enabled-groups,cn=groups,cn=accounts,dc=example,dc=com',
-        :group_objectclass => 'organizationalRole',
-        :group_id_attribute => 'cn',
-        :group_name_attribute => 'cn',
-        :group_member_attribute => 'roleOccupant',
-        :group_desc_attribute => 'description',
-        :group_attribute_ignore => '',
-        :group_allow_create => 'False',
-        :group_allow_update => 'False',
-        :group_allow_delete => 'False',
-        :group_additional_attribute_mapping => '',
-        :chase_referrals => 'False',
-        :use_tls => 'False',
-        :tls_cacertdir => '/etc/ssl/certs/',
-        :tls_cacertfile => '/etc/ssl/certs/ca-certificates.crt',
-        :tls_req_cert => 'demand',
-        :identity_driver => 'ldap',
-        :use_pool => 'True',
-        :pool_size => 20,
-        :pool_retry_max => 2,
-        :pool_retry_delay => 0.2,
-        :pool_connection_timeout => 222,
-        :pool_connection_lifetime => 222,
-        :use_auth_pool => 'True',
-        :auth_pool_size => 20,
-        :auth_pool_connection_lifetime => 200,
+        :role_tree_dn                         => 'ou=roles,ou=openstack,dc=example,dc=com',
+        :role_filter                          => '',
+        :role_objectclass                     => 'organizationalRole',
+        :role_id_attribute                    => 'cn',
+        :role_name_attribute                  => 'ou',
+        :role_member_attribute                => 'roleOccupant',
+        :role_attribute_ignore                => 'description',
+        :role_allow_create                    => 'True',
+        :role_allow_update                    => 'True',
+        :role_allow_delete                    => 'True',
+        :role_additional_attribute_mapping    => '',
+        :group_tree_dn                        => 'ou=groups,ou=openstack,dc=example,dc=com',
+        :group_filter                         => 'cn=enabled-groups,cn=groups,cn=accounts,dc=example,dc=com',
+        :group_objectclass                    => 'organizationalRole',
+        :group_id_attribute                   => 'cn',
+        :group_name_attribute                 => 'cn',
+        :group_member_attribute               => 'roleOccupant',
+        :group_desc_attribute                 => 'description',
+        :group_attribute_ignore               => '',
+        :group_additional_attribute_mapping   => '',
+        :chase_referrals                      => 'False',
+        :use_tls                              => 'False',
+        :tls_cacertdir                        => '/etc/ssl/certs/',
+        :tls_cacertfile                       => '/etc/ssl/certs/ca-certificates.crt',
+        :tls_req_cert                         => 'demand',
+        :identity_driver                      => 'ldap',
+        :use_pool                             => 'True',
+        :pool_size                            => 20,
+        :pool_retry_max                       => 2,
+        :pool_retry_delay                     => 0.2,
+        :pool_connection_timeout              => 222,
+        :pool_connection_lifetime             => 222,
+        :use_auth_pool                        => 'True',
+        :auth_pool_size                       => 20,
+        :auth_pool_connection_lifetime        => 200,
       }
     end
-    it { is_expected.to contain_package('python-ldap') }
     it { is_expected.to contain_package('python-ldappool') }
     it 'should have basic params' do
       # basic params
@@ -102,6 +96,7 @@ describe 'keystone::ldap' do
       is_expected.to contain_keystone_config('ldap/user_objectclass').with_value('inetUser')
       is_expected.to contain_keystone_config('ldap/user_id_attribute').with_value('uid')
       is_expected.to contain_keystone_config('ldap/user_name_attribute').with_value('cn')
+      is_expected.to contain_keystone_config('ldap/user_description_attribute').with_value('description')
       is_expected.to contain_keystone_config('ldap/user_mail_attribute').with_value('mail')
       is_expected.to contain_keystone_config('ldap/user_enabled_attribute').with_value('UserAccountControl')
       is_expected.to contain_keystone_config('ldap/user_enabled_mask').with_value('2')
@@ -110,9 +105,6 @@ describe 'keystone::ldap' do
       is_expected.to contain_keystone_config('ldap/user_attribute_ignore').with_value('')
       is_expected.to contain_keystone_config('ldap/user_default_project_id_attribute').with_value('defaultProject')
       is_expected.to contain_keystone_config('ldap/user_tree_dn').with_value('cn=users,dc=example,dc=com')
-      is_expected.to contain_keystone_config('ldap/user_allow_create').with_value('False')
-      is_expected.to contain_keystone_config('ldap/user_allow_update').with_value('False')
-      is_expected.to contain_keystone_config('ldap/user_allow_delete').with_value('False')
       is_expected.to contain_keystone_config('ldap/user_pass_attribute').with_value('krbPassword')
       is_expected.to contain_keystone_config('ldap/user_enabled_emulation').with_value('True')
       is_expected.to contain_keystone_config('ldap/user_enabled_emulation_dn').with_value('cn=openstack-enabled,cn=groups,cn=accounts,dc=example,dc=com')
@@ -158,9 +150,6 @@ describe 'keystone::ldap' do
       is_expected.to contain_keystone_config('ldap/group_desc_attribute').with_value('description')
       is_expected.to contain_keystone_config('ldap/group_name_attribute').with_value('cn')
       is_expected.to contain_keystone_config('ldap/group_attribute_ignore').with_value('')
-      is_expected.to contain_keystone_config('ldap/group_allow_create').with_value('False')
-      is_expected.to contain_keystone_config('ldap/group_allow_update').with_value('False')
-      is_expected.to contain_keystone_config('ldap/group_allow_delete').with_value('False')
       is_expected.to contain_keystone_config('ldap/group_additional_attribute_mapping').with_value('')
 
       # referrals
@@ -192,7 +181,6 @@ describe 'keystone::ldap' do
     let :params do
       { :manage_packages => false }
     end
-      it { is_expected.to_not contain_package('python-ldap') }
       it { is_expected.to_not contain_package('python-ldappool') }
   end
 
