@@ -3,10 +3,7 @@ $LOAD_PATH.push(File.join(File.dirname(__FILE__), 'fixtures', 'modules', 'openst
 require 'puppetlabs_spec_helper/module_spec_helper'
 require 'shared_examples'
 require 'webmock/rspec'
-
-require 'puppet-openstack_spec_helper/defaults'
-require 'rspec-puppet-facts'
-include RspecPuppetFacts
+require 'puppet-openstack_spec_helper/facts'
 
 # LP1492636 - Cohabitation of compile matcher and webmock
 WebMock.disable_net_connect!(:allow => "169.254.169.254")
@@ -14,11 +11,6 @@ WebMock.disable_net_connect!(:allow => "169.254.169.254")
 RSpec.configure do |c|
   c.alias_it_should_behave_like_to :it_configures, 'configures'
   c.alias_it_should_behave_like_to :it_raises, 'raises'
-  # TODO(aschultz): remove this after all tests converted to use OSDefaults
-  # instead of referencing @default_facts
-  c.before :each do
-    @default_facts = OSDefaults.get_facts
-  end
 end
 
 RSpec::Matchers.define :be_absent do
